@@ -7,7 +7,6 @@ use warnings;
 
 use Scalar::Util qw(blessed);
 use Storable;
-use YAML::Syck;
 
 =head1 NAME
 
@@ -219,9 +218,7 @@ sub stringify {
   
   my $return = $self->code;
   $return .= " - " . $self->message if length($self->message);
-  # don't call the ->data method here, as we don't really need to clone the data
-  $return .= "\nData:\n".Dump($self->{-data}) if defined $self->{-data};
-  return $return . "\nStack trace:\n$strace"
+  return $return . ":\n$strace"
 }
 
 =back
